(howto-index)=

# How-to guides

This section contains step-by-step guides
showing you how to accomplish specific tasks with `vak`,
like training a model with your own spectrograms
or your own format for annotating vocalizations.

```{toctree}
:maxdepth: 1

howto_user_spect
howto_user_annot
```
